@@ -8,10 +8,7 @@ pub use read::Reader;
 pub use write::Writer;
 
 /// Splits a `TcpStream` into a `Reader` and `Writer`
-pub fn split_stream<H, M, O>(
-    stream: TcpStream,
-    seri_opt: O,
-) -> (Reader<H, M, O>, Writer<H, M, O>)
+pub fn split_stream<H, M, O>(stream: TcpStream, seri_opt: O) -> (Reader<H, M, O>, Writer<H, M, O>)
 where
     H: crate::header::IsHeader + Clone,
     M: Serialize + DeserializeOwned,
@@ -25,7 +22,7 @@ where
 }
 
 /// Attempts to join a `Reader` and `Writer` into a `TcpStream`
-/// 
+///
 /// # Errors
 /// if the halfs did not originate from the same `TcpStream`
 pub fn join_stream<H, M, O>(
@@ -38,4 +35,4 @@ where
     O: bincode::Options + Clone,
 {
     read_half.into_socket().reunite(write_half.into_socket())
-}
\ No newline at end of file
+}
